==> jupyter-forward-2021.5.11.tar.gz: jupyter-forward-2021.5.11/CHANGELOG.md <==
# Changelog

## v2021.5.11

([full changelog](https://github.com/NCAR/jupyter-forward/compare/69debd1e535f5089c7236ce254c052d31ebf4a55...caf320d95fffcb89b623bd211a9664b98c821ff1))

- Use long host name [#88](https://github.com/NCAR/jupyter-forward/pull/88) ([@andersy005](https://github.com/andersy005))
- Force login shell [#87](https://github.com/NCAR/jupyter-forward/pull/87) ([@andersy005](https://github.com/andersy005))
- Bump pre-commit/action from v2.0.2 to v2.0.3 [#85](https://github.com/NCAR/jupyter-forward/pull/85) ([@dependabot](https://github.com/dependabot))
- 🔨 Code refactoring [#84](https://github.com/NCAR/jupyter-forward/pull/84) ([@andersy005](https://github.com/andersy005))
- 🐛 Catch SSH no authentication exception [#83](https://github.com/NCAR/jupyter-forward/pull/83) ([@andersy005](https://github.com/andersy005))
- Use "source activate" instead of "conda activate" [#82](https://github.com/NCAR/jupyter-forward/pull/82) ([@rsignell-usgs](https://github.com/rsignell-usgs))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2021-04-14&to=2021-05-12&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2021-04-14..2021-05-12&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2021-04-14..2021-05-12&type=Issues) | [@mnlevy1981](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Amnlevy1981+updated%3A2021-04-14..2021-05-12&type=Issues) | [@rsignell-usgs](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Arsignell-usgs+updated%3A2021-04-14..2021-05-12&type=Issues)

## v2021.4.13

([full changelog](https://github.com/NCAR/jupyter-forward/compare/20096779c4d562fcd096b6b09b91ccc8b0851146...9916ccb95419751977decb15d22ee7986470cb67))

- 🔨 Enhanced logging [#77](https://github.com/NCAR/jupyter-forward/pull/77) ([@andersy005](https://github.com/andersy005))
- 👷 Trigger CI on push or pull_request but not both [#76](https://github.com/NCAR/jupyter-forward/pull/76) ([@andersy005](https://github.com/andersy005))
- Bump styfle/cancel-workflow-action from 0.8.0 to 0.9.0 [#75](https://github.com/NCAR/jupyter-forward/pull/75) ([@dependabot](https://github.com/dependabot))
- Bump pre-commit/action from v2.0.0 to v2.0.2 [#74](https://github.com/NCAR/jupyter-forward/pull/74) ([@dependabot](https://github.com/dependabot))
- 📚 Enable comments in docs via sphinx-comments [#71](https://github.com/NCAR/jupyter-forward/pull/71) ([@andersy005](https://github.com/andersy005))
- Handle missing SSH key error [#69](https://github.com/NCAR/jupyter-forward/pull/69) ([@andersy005](https://github.com/andersy005))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2021-03-03&to=2021-04-14&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2021-03-03..2021-04-14&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2021-03-03..2021-04-14&type=Issues) | [@mnlevy1981](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Amnlevy1981+updated%3A2021-03-03..2021-04-14&type=Issues)

## v2021.3.3

([full changelog](https://github.com/NCAR/jupyter-forward/compare/27dc14741783911c078213c351732fccbb1f6561...a2847f88c718a8f9cc54ab6a75a4cc70121fbda2))

- Tcsh support [#67](https://github.com/NCAR/jupyter-forward/pull/67) ([@mnlevy1981](https://github.com/mnlevy1981))
- Bump styfle/cancel-workflow-action from 0.7.0 to 0.8.0 [#64](https://github.com/NCAR/jupyter-forward/pull/64) ([@dependabot](https://github.com/dependabot))
- Bump pypa/gh-action-pypi-publish from v1.4.1 to v1.4.2 [#63](https://github.com/NCAR/jupyter-forward/pull/63) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2021-02-06&to=2021-03-03&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2021-02-06..2021-03-03&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2021-02-06..2021-03-03&type=Issues) | [@mnlevy1981](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Amnlevy1981+updated%3A2021-02-06..2021-03-03&type=Issues)

## v2021.2.5

([full changelog](https://github.com/NCAR/jupyter-forward/compare/54b2fee0316cd9edf6d3957805b77f515b3fe5b5...4e9951b1f38b81dd5c12fc8db15205fc082f1b58))

- Add development setup [#61](https://github.com/NCAR/jupyter-forward/pull/61) ([@andersy005](https://github.com/andersy005))
- Update PyPI GH action [#60](https://github.com/NCAR/jupyter-forward/pull/60) ([@andersy005](https://github.com/andersy005))
- Add Jupyter executable sanity checks [#59](https://github.com/NCAR/jupyter-forward/pull/59) ([@andersy005](https://github.com/andersy005))
- Pretty print logs with rich [#58](https://github.com/NCAR/jupyter-forward/pull/58) ([@andersy005](https://github.com/andersy005))
- Bump styfle/cancel-workflow-action from 0.6.0 to 0.7.0 [#57](https://github.com/NCAR/jupyter-forward/pull/57) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2020-12-04&to=2021-02-06&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2020-12-04..2021-02-06&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2020-12-04..2021-02-06&type=Issues)

## v2020.12.3

- 🔧 Update setuptools-scm settings and Update pypi GHA [#52](https://github.com/NCAR/jupyter-forward/pull/52) ([@andersy005](https://github.com/andersy005))
- ✨ Update authentication scheme [#51](https://github.com/NCAR/jupyter-forward/pull/51) ([@mnlevy1981](https://github.com/mnlevy1981))
- 💚 Fix CI [#50](https://github.com/NCAR/jupyter-forward/pull/50) ([@andersy005](https://github.com/andersy005))
- 🐛 Raise SystemExit when port-forwarding is enabled and local port is not available [#48](https://github.com/NCAR/jupyter-forward/pull/48) ([@andersy005](https://github.com/andersy005))
- Add conda installation info [#47](https://github.com/NCAR/jupyter-forward/pull/47) ([@andersy005](https://github.com/andersy005))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2020-10-28&to=2020-12-03&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2020-10-28..2020-12-03&type=Issues) | [@mnlevy1981](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Amnlevy1981+updated%3A2020-10-28..2020-12-03&type=Issues)

## v2020.10.27

- ⚡ Use try block to exit gracefully. PR [#45](https://github.com/NCAR/jupyter-forward/pull/45) by [@andersy005](https://github.com/andersy005)

- ⚡ Make `log_dir` usage consistent throughout the `RemoteRunner`. PR [#44](https://github.com/NCAR/jupyter-forward/pull/44) by [@andersy005](https://github.com/andersy005)

- ✨ Add `--shell` option. PR [#43](https://github.com/NCAR/jupyter-forward/pull/43) by [@andersy005](https://github.com/andersy005)

- 📚 Update doc references in regards to `--launch-command` option. PR [#42](https://github.com/NCAR/jupyter-forward/pull/42) by [@andersy005](https://github.com/andersy005)

- 📝 Update usage/installation docs. PR [#41](https://github.com/NCAR/jupyter-forward/pull/41) by [@andersy005](https://github.com/andersy005)

- ✨ Add `--version` flag. PR [#39](https://github.com/NCAR/jupyter-forward/pull/39) by [@andersy005](https://github.com/andersy005)

- 📚 Enable documentation on Readthedocs. PR [#37](https://github.com/NCAR/jupyter-forward/pull/37) by [@andersy005](https://github.com/andersy005).

## v2020.10.22.1

- Use setuptools-scm for versioning. PR [#36](https://github.com/NCAR/jupyter-forward/pull/36) by [@andersy005](https://github.com/andersy005).

- Fix changelog formatting. PR [#35](https://github.com/NCAR/jupyter-forward/pull/35) by [@andersy005](https://github.com/andersy005).

- Update PyPI release action. PR [#34](https://github.com/NCAR/jupyter-forward/pull/34) by [@andersy005](https://github.com/andersy005).

## v2020.10.22 and v2020.10.21

- Update README. PR [#33](https://github.com/NCAR/jupyter-forward/pull/33) by [@andersy005](https://github.com/andersy005).

- Fix Header in `latest changes` GH action. PR [#32](https://github.com/NCAR/jupyter-forward/pull/32) by [@andersy005](https://github.com/andersy005).

- Create release via GitHub action. PR [#31](https://github.com/NCAR/jupyter-forward/pull/31) by [@andersy005](https://github.com/andersy005).

- ✨ Add `--launch-command` option. PR [#28](https://github.com/NCAR/jupyter-forward/pull/28) by [@andersy005](https://github.com/andersy005)

- ✨ Use fabric for port-forwarding. PR [#15](https://github.com/NCAR/jupyter-forward/pull/15) by [@andersy005](https://github.com/andersy005) & [@mnlevy1981](https://github.com/mnlevy1981)

- 🐛 Fix auth issue when authenticating with DUO app. PR [#13](https://github.com/NCAR/jupyter-forward/pull139) by [@andersy005](https://github.com/andersy005)

- 📚 Add motivation for jupyter-forward. PR [#12](https://github.com/NCAR/jupyter-forward/pull/12) by [@jukent](https://github.com/jukent)

- ✨ Interrupt a running jupyter server with `Ctrl+C`. PR [#9](https://github.com/NCAR/jupyter-forward/pull/9) by [@andersy005](https://github.com/andersy005)

- 🐛 Fix SSH port-forwarding. PR [#8](https://github.com/NCAR/jupyter-forward/pull/8) by [@andersy005](https://github.com/andersy005)

- ✨ Launch Jupyter Lab with `asynchronous=True`. PR [#4](https://github.com/NCAR/jupyter-forward/pull/4) by [@andersy005](https://github.com/andersy005) & [@mnlevy1981](https://github.com/mnlevy1981)

==> jupyter-forward-2021.8.17.tar.gz: jupyter-forward-2021.8.17/CHANGELOG.md <==
# Changelog

## v2021.8.17

([full changelog](https://github.com/NCAR/jupyter-forward/compare/0dbaf5f99a9b80947ff72b1790b891e22863a033...e68dfc3c203506650fc361583cad5bdf8aa58c49))

### Enhancements made

- Add `--notebook` option [#95](https://github.com/NCAR/jupyter-forward/pull/95) ([@andersy005](https://github.com/andersy005))

### Bugs fixed

- Use Try except block for conda/source activate [#94](https://github.com/NCAR/jupyter-forward/pull/94) ([@andersy005](https://github.com/andersy005))

### Maintenance and upkeep improvements

- [pre-commit.ci] pre-commit autoupdate [#99](https://github.com/NCAR/jupyter-forward/pull/99) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump styfle/cancel-workflow-action from 0.9.0 to 0.9.1 [#98](https://github.com/NCAR/jupyter-forward/pull/98) ([@dependabot](https://github.com/dependabot))
- Update pre-commit hooks [#97](https://github.com/NCAR/jupyter-forward/pull/97) ([@andersy005](https://github.com/andersy005))
- Bump codecov/codecov-action from 1 to 2.0.2 [#96](https://github.com/NCAR/jupyter-forward/pull/96) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2021-05-12&to=2021-08-17&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2021-05-12..2021-08-17&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2021-05-12..2021-08-17&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Apre-commit-ci+updated%3A2021-05-12..2021-08-17&type=Issues)

## v2021.5.11

([full changelog](https://github.com/NCAR/jupyter-forward/compare/69debd1e535f5089c7236ce254c052d31ebf4a55...caf320d95fffcb89b623bd211a9664b98c821ff1))

- Use long host name [#88](https://github.com/NCAR/jupyter-forward/pull/88) ([@andersy005](https://github.com/andersy005))
- Force login shell [#87](https://github.com/NCAR/jupyter-forward/pull/87) ([@andersy005](https://github.com/andersy005))
- Bump pre-commit/action from v2.0.2 to v2.0.3 [#85](https://github.com/NCAR/jupyter-forward/pull/85) ([@dependabot](https://github.com/dependabot))
- 🔨 Code refactoring [#84](https://github.com/NCAR/jupyter-forward/pull/84) ([@andersy005](https://github.com/andersy005))
- 🐛 Catch SSH no authentication exception [#83](https://github.com/NCAR/jupyter-forward/pull/83) ([@andersy005](https://github.com/andersy005))
- Use "source activate" instead of "conda activate" [#82](https://github.com/NCAR/jupyter-forward/pull/82) ([@rsignell-usgs](https://github.com/rsignell-usgs))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2021-04-14&to=2021-05-12&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2021-04-14..2021-05-12&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2021-04-14..2021-05-12&type=Issues) | [@mnlevy1981](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Amnlevy1981+updated%3A2021-04-14..2021-05-12&type=Issues) | [@rsignell-usgs](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Arsignell-usgs+updated%3A2021-04-14..2021-05-12&type=Issues)

## v2021.4.13

([full changelog](https://github.com/NCAR/jupyter-forward/compare/20096779c4d562fcd096b6b09b91ccc8b0851146...9916ccb95419751977decb15d22ee7986470cb67))

- 🔨 Enhanced logging [#77](https://github.com/NCAR/jupyter-forward/pull/77) ([@andersy005](https://github.com/andersy005))
- 👷 Trigger CI on push or pull_request but not both [#76](https://github.com/NCAR/jupyter-forward/pull/76) ([@andersy005](https://github.com/andersy005))
- Bump styfle/cancel-workflow-action from 0.8.0 to 0.9.0 [#75](https://github.com/NCAR/jupyter-forward/pull/75) ([@dependabot](https://github.com/dependabot))
- Bump pre-commit/action from v2.0.0 to v2.0.2 [#74](https://github.com/NCAR/jupyter-forward/pull/74) ([@dependabot](https://github.com/dependabot))
- 📚 Enable comments in docs via sphinx-comments [#71](https://github.com/NCAR/jupyter-forward/pull/71) ([@andersy005](https://github.com/andersy005))
- Handle missing SSH key error [#69](https://github.com/NCAR/jupyter-forward/pull/69) ([@andersy005](https://github.com/andersy005))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2021-03-03&to=2021-04-14&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2021-03-03..2021-04-14&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2021-03-03..2021-04-14&type=Issues) | [@mnlevy1981](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Amnlevy1981+updated%3A2021-03-03..2021-04-14&type=Issues)

## v2021.3.3

([full changelog](https://github.com/NCAR/jupyter-forward/compare/27dc14741783911c078213c351732fccbb1f6561...a2847f88c718a8f9cc54ab6a75a4cc70121fbda2))

- Tcsh support [#67](https://github.com/NCAR/jupyter-forward/pull/67) ([@mnlevy1981](https://github.com/mnlevy1981))
- Bump styfle/cancel-workflow-action from 0.7.0 to 0.8.0 [#64](https://github.com/NCAR/jupyter-forward/pull/64) ([@dependabot](https://github.com/dependabot))
- Bump pypa/gh-action-pypi-publish from v1.4.1 to v1.4.2 [#63](https://github.com/NCAR/jupyter-forward/pull/63) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2021-02-06&to=2021-03-03&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2021-02-06..2021-03-03&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2021-02-06..2021-03-03&type=Issues) | [@mnlevy1981](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Amnlevy1981+updated%3A2021-02-06..2021-03-03&type=Issues)

## v2021.2.5

([full changelog](https://github.com/NCAR/jupyter-forward/compare/54b2fee0316cd9edf6d3957805b77f515b3fe5b5...4e9951b1f38b81dd5c12fc8db15205fc082f1b58))

- Add development setup [#61](https://github.com/NCAR/jupyter-forward/pull/61) ([@andersy005](https://github.com/andersy005))
- Update PyPI GH action [#60](https://github.com/NCAR/jupyter-forward/pull/60) ([@andersy005](https://github.com/andersy005))
- Add Jupyter executable sanity checks [#59](https://github.com/NCAR/jupyter-forward/pull/59) ([@andersy005](https://github.com/andersy005))
- Pretty print logs with rich [#58](https://github.com/NCAR/jupyter-forward/pull/58) ([@andersy005](https://github.com/andersy005))
- Bump styfle/cancel-workflow-action from 0.6.0 to 0.7.0 [#57](https://github.com/NCAR/jupyter-forward/pull/57) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2020-12-04&to=2021-02-06&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2020-12-04..2021-02-06&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Adependabot+updated%3A2020-12-04..2021-02-06&type=Issues)

## v2020.12.3

- 🔧 Update setuptools-scm settings and Update pypi GHA [#52](https://github.com/NCAR/jupyter-forward/pull/52) ([@andersy005](https://github.com/andersy005))
- ✨ Update authentication scheme [#51](https://github.com/NCAR/jupyter-forward/pull/51) ([@mnlevy1981](https://github.com/mnlevy1981))
- 💚 Fix CI [#50](https://github.com/NCAR/jupyter-forward/pull/50) ([@andersy005](https://github.com/andersy005))
- 🐛 Raise SystemExit when port-forwarding is enabled and local port is not available [#48](https://github.com/NCAR/jupyter-forward/pull/48) ([@andersy005](https://github.com/andersy005))
- Add conda installation info [#47](https://github.com/NCAR/jupyter-forward/pull/47) ([@andersy005](https://github.com/andersy005))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/jupyter-forward/graphs/contributors?from=2020-10-28&to=2020-12-03&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Aandersy005+updated%3A2020-10-28..2020-12-03&type=Issues) | [@mnlevy1981](https://github.com/search?q=repo%3ANCAR%2Fjupyter-forward+involves%3Amnlevy1981+updated%3A2020-10-28..2020-12-03&type=Issues)

## v2020.10.27

- ⚡ Use try block to exit gracefully. PR [#45](https://github.com/NCAR/jupyter-forward/pull/45) by [@andersy005](https://github.com/andersy005)

- ⚡ Make `log_dir` usage consistent throughout the `RemoteRunner`. PR [#44](https://github.com/NCAR/jupyter-forward/pull/44) by [@andersy005](https://github.com/andersy005)

- ✨ Add `--shell` option. PR [#43](https://github.com/NCAR/jupyter-forward/pull/43) by [@andersy005](https://github.com/andersy005)

- 📚 Update doc references in regards to `--launch-command` option. PR [#42](https://github.com/NCAR/jupyter-forward/pull/42) by [@andersy005](https://github.com/andersy005)

- 📝 Update usage/installation docs. PR [#41](https://github.com/NCAR/jupyter-forward/pull/41) by [@andersy005](https://github.com/andersy005)

- ✨ Add `--version` flag. PR [#39](https://github.com/NCAR/jupyter-forward/pull/39) by [@andersy005](https://github.com/andersy005)

- 📚 Enable documentation on Readthedocs. PR [#37](https://github.com/NCAR/jupyter-forward/pull/37) by [@andersy005](https://github.com/andersy005).

## v2020.10.22.1

- Use setuptools-scm for versioning. PR [#36](https://github.com/NCAR/jupyter-forward/pull/36) by [@andersy005](https://github.com/andersy005).

- Fix changelog formatting. PR [#35](https://github.com/NCAR/jupyter-forward/pull/35) by [@andersy005](https://github.com/andersy005).

- Update PyPI release action. PR [#34](https://github.com/NCAR/jupyter-forward/pull/34) by [@andersy005](https://github.com/andersy005).

## v2020.10.22 and v2020.10.21

- Update README. PR [#33](https://github.com/NCAR/jupyter-forward/pull/33) by [@andersy005](https://github.com/andersy005).

- Fix Header in `latest changes` GH action. PR [#32](https://github.com/NCAR/jupyter-forward/pull/32) by [@andersy005](https://github.com/andersy005).

- Create release via GitHub action. PR [#31](https://github.com/NCAR/jupyter-forward/pull/31) by [@andersy005](https://github.com/andersy005).

- ✨ Add `--launch-command` option. PR [#28](https://github.com/NCAR/jupyter-forward/pull/28) by [@andersy005](https://github.com/andersy005)

- ✨ Use fabric for port-forwarding. PR [#15](https://github.com/NCAR/jupyter-forward/pull/15) by [@andersy005](https://github.com/andersy005) & [@mnlevy1981](https://github.com/mnlevy1981)

- 🐛 Fix auth issue when authenticating with DUO app. PR [#13](https://github.com/NCAR/jupyter-forward/pull139) by [@andersy005](https://github.com/andersy005)

- 📚 Add motivation for jupyter-forward. PR [#12](https://github.com/NCAR/jupyter-forward/pull/12) by [@jukent](https://github.com/jukent)

- ✨ Interrupt a running jupyter server with `Ctrl+C`. PR [#9](https://github.com/NCAR/jupyter-forward/pull/9) by [@andersy005](https://github.com/andersy005)

- 🐛 Fix SSH port-forwarding. PR [#8](https://github.com/NCAR/jupyter-forward/pull/8) by [@andersy005](https://github.com/andersy005)

- ✨ Launch Jupyter Lab with `asynchronous=True`. PR [#4](https://github.com/NCAR/jupyter-forward/pull/4) by [@andersy005](https://github.com/andersy005) & [@mnlevy1981](https://github.com/mnlevy1981)
